@@ -2,4 +2,4 @@
 
 from .rpn import main
 
-__all__ = ['main']
+__all__ = ["main"]
